document.addEventListener('DOMContentLoaded', function() {
    document.querySelectorAll( 'table.variations select' )
        .forEach( function( select ) {
            select.selectOptionByValue = function (value) {
                this.value = true;
                select.parentElement.querySelectorAll('input[type="radio"]').forEach(function (radio) {
                    radio.checked = radio.value === value;
                });

                this.dispatchEvent(new CustomEvent('change'));
            };
            select.querySelectorAll( 'option' ).forEach( selectOptionCallback );
            select.style.display = 'none';
        } );
});

function selectOptionCallback( option ) {
    if( ! option.value ) {
        return;
    }

    const selectOfOption = option.parentElement;
    const radio = document.createElement( 'input' );
    radio.type = 'radio';
    radio.name = selectOfOption.name;
    radio.value = option.value;
    radio.checked = option.selected;
    radio.setAttribute('id', `${selectOfOption.id}-${option.value}`);
    const label = document.createElement( 'label' );
    label.htmlFor = `${selectOfOption.id}-${option.value}`;
    label.style.padding = '5px';

    const dataUseValueAsPreviewImageColor = option.attributes.getNamedItem('data-use-value-as-preview-image-color');
    const dataImageUrlAttr = option.attributes.getNamedItem('data-image-url');
    if (dataImageUrlAttr) {
        const labelDiv = document.createElement('div');
        labelDiv.style.display = 'flex';
        labelDiv.style.flexDirection = 'column';
        const imageDiv = document.createElement('div');
        imageDiv.style.textAlign = 'center';
        imageDiv.style.lineHeight = '0';
        const image = document.createElement('img');
        image.src = dataImageUrlAttr.value;
        image.style.maxWidth = '36px';
        image.style.maxHeight = '36px';
        imageDiv.appendChild(image);
        labelDiv.appendChild(imageDiv);
        const nameDiv = document.createElement('div');
        nameDiv.innerText = option.text;
        nameDiv.style.lineHeight = 'normal';
        nameDiv.style.textAlign = 'center';
        labelDiv.appendChild(nameDiv);
        label.appendChild(labelDiv);
    } else if (dataUseValueAsPreviewImageColor && dataUseValueAsPreviewImageColor.value === 'true') {
        let labelIsActive = false;
        const dataLabelIsActive = option.attributes.getNamedItem('data-label-is-active');
        if (dataLabelIsActive) {
            labelIsActive = dataLabelIsActive.value === 'true';
        }

        const labelDiv = document.createElement('div');
        labelDiv.style.display = 'flex';
        labelDiv.style.flexDirection = 'column';
        const previewColorDiv = document.createElement('div');
        previewColorDiv.style.textAlign = 'center';
        previewColorDiv.style.lineHeight = '0';
        previewColorDiv.style.marginLeft = 'auto';
        previewColorDiv.style.marginRight = 'auto';
        const previewColor = document.createElement('div');
        previewColor.style.width = '36px';
        previewColor.style.height = '36px';
        previewColor.style.backgroundColor = option.value;
        previewColorDiv.appendChild(previewColor);
        labelDiv.appendChild(previewColorDiv);
        if (labelIsActive) {
            const nameDiv = document.createElement('div');
            nameDiv.innerText = option.text;
            nameDiv.style.lineHeight = 'normal';
            nameDiv.style.textAlign = 'center';
            labelDiv.appendChild(nameDiv);
        }
        label.appendChild(labelDiv);

    } else {
        label.appendChild( document.createTextNode( ` ${option.text} ` ) );
    }

    let selectionFlexContainer = document.getElementById( `${selectOfOption.id}-selection-flex-container` );
    if (!selectionFlexContainer) {
        selectionFlexContainer = document.createElement('div');
        selectionFlexContainer.id = `${selectOfOption.id}-selection-flex-container`;
        selectionFlexContainer.style.display = 'flex';
        selectionFlexContainer.style.flexWrap = 'wrap';
        selectionFlexContainer.style.width = '100%';

        selectOfOption.closest( 'td' ).appendChild( selectionFlexContainer );
    }

    const span = document.createElement( 'span' );
    span.style.marginLeft = '5px';
    span.style.marginRight = '5px';
    span.appendChild( radio );
    span.appendChild( label );

    selectionFlexContainer.appendChild( span );

    radio.addEventListener( 'click', function() {
        selectOfOption.value = radio.value;
        selectOfOption.dispatchEvent(new CustomEvent('change'));
        const variations_form = document.querySelector( 'form.variations_form' );
        if (variations_form) {
            variations_form.dispatchEvent(new CustomEvent('check_variations'));
        }
    } );
}
